@@ -1,3 +1,4 @@
+use interface::FieldValue;
 use std::collections::HashMap;
 use std::path::PathBuf;
 use std::sync::Arc;
@@ -9,26 +10,19 @@ pub type ClientRC = Arc<Client>;
 /// The metadata of a blob.
 #[derive(Clone, Debug, Default, PartialEq, Eq)]
 pub struct FileMetadata {
-    /// The name of this file/folder. Does not need to be unique.
-    pub name: String,
-
     /// The key/value pairs for this file.
-    pub metadata: HashMap<String, String>,
+    pub fields: HashMap<String, FieldValue>,
 
     /// The tags for this file.
     pub tags: Vec<String>,
-
-    /// This file's parent IDs.
-    pub parents: Vec<String>,
-
-    /// This file's size, in bytes.
-    pub size: u64,
 }
 
 impl FileMetadata {
     pub fn new<S: Into<String>>(name: S) -> Self {
+        let mut fields: HashMap<String, FieldValue> = HashMap::new();
+        fields.insert("name".into(), FieldValue::Str(name.into()));
         Self {
-            name: name.into(),
+            fields,
             ..Default::default()
         }
     }
@@ -40,20 +34,8 @@ impl FileMetadata {
     }
 
     #[must_use]
-    pub fn with_meta<K: Into<String>, V: Into<String>>(mut self, key: K, value: V) -> Self {
-        self.metadata.insert(key.into(), value.into());
-        self
-    }
-
-    #[must_use]
-    pub fn with_parent<P: Into<String>>(mut self, parent: P) -> Self {
-        self.parents.push(parent.into());
-        self
-    }
-
-    #[must_use]
-    pub fn with_size(mut self, size: u64) -> Self {
-        self.size = size;
+    pub fn with_field<K: Into<String>, V: Into<FieldValue>>(mut self, key: K, value: V) -> Self {
+        self.fields.insert(key.into(), value.into());
         self
     }
 }
@@ -64,11 +46,8 @@ pub struct UploadRequest {
     pub path: PathBuf,
 
     /// The metadata of the file to upload.
-    pub metadata: HashMap<String, String>,
+    pub fields: HashMap<String, String>,
 
     /// The tags of the file to upload.
     pub tags: Vec<String>,
-
-    /// The parent id of the file to upload.
-    pub parent_id: Option<String>,
 }
